import json, sys, random
with open(sys.argv[2], 'w', encoding='utf-8') as f:
	j = json.load(open(sys.argv[1], 'r', encoding='utf-8'))
	random.shuffle(j['articles'])
	for i in j['articles']:
		if i.get('article_title', '')!=None and '[公告]' not in i.get('article_title', '') and 'Re' not in i.get('article_title', ''):
			if len(i.get('article_title', '')) >= 9:
				f.write(i.get('article_title', '').replace('\n', '') + '\n')
			f.write(i.get('content', '').replace('\n', '') + '\n')


from udicOpenData.dictionary import *
import jieba.posseg as pseg
import json, os, re
DIR_NAME = os.path.dirname(os.path.abspath(__file__))

STOPWORD_JSON = json.load(open(os.path.join(DIR_NAME, 'stopwords.json'), 'r'))

def rmsw(doc, flag=False):
    '''
    parameter:
      flag: boolean, if true will return segment with pos.
    '''
    def is_chinese(keyword):
        for uchar in keyword:
            if '\u4e00' <= uchar<='\u9fff':
                continue
            else:
                return False
        return True

    def is_english(keyword):
        if not is_chinese(keyword) and keyword.isalpha():
            return True
        return False

    doc = doc.strip()

    # flag means showing part of speech
    if flag:
        return (tuple(i) for i in pseg.cut(doc)
            if i.word not in STOPWORD_JSON 
            and (is_chinese(i.word) or (is_english(i.word) and len(i.word) >= 2))
            and i.word not in ['\xa0', '\xc2'] 
            and i.word.isdigit() == False 
        )
    else:
        return (i for i in jieba.cut(doc)
            if i not in STOPWORD_JSON 
            and (is_chinese(i) or (is_english(i) and len(i) >= 2)) 
            and i not in ['\xa0', '\xc2']
            and i.isdigit() == False 
        )


import jieba, json, sys, os
import jieba.posseg as pseg
stopwords = json.load(open('stopwords.json', 'r'))
jieba.load_userdict(os.path.join('dictionary', 'dict.txt.big.txt'))
jieba.load_userdict(os.path.join("dictionary", "NameDict_Ch_v2"))

def removeStopWords(key_and_value, rmstop=sys.argv[3]):
	def condition(x):
		x = list(x)
		word, flag = x[0], x[1]
		if len(word) > 1 and flag!='eng' and flag != 'm' and flag !='mq' and word not in stopwords:
			return True
		return False

	key, value = key_and_value
	if rmstop == 'True':
		key = filter(condition, pseg.cut(key))
		key = list(map(lambda x:list(x)[0], key))
		value = filter(condition, pseg.cut(value))
		value = list(map(lambda x:list(x)[0], value))
	else:
		key = jieba.lcut(key)
		value = jieba.lcut(value.replace('\n', '').strip())
	return {'key':key, 'value':value}

with open(sys.argv[1], 'r') as f:
	f = json.load(f)
	result = list(map(removeStopWords, f.items()))

with open(sys.argv[2], 'w') as f:
	json.dump(result, f)